@@ -6,15 +6,15 @@
  * modify it under the terms of the GNU Lesser General Public License
  * as published by the Free Software Foundation; either version 2.1
  * of the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 #include <stdio.h>
 
@@ -23,6 +23,8 @@
 #include <gtkdatabox_points.h>
 #include <gtkdatabox_lines.h>
 #include <gtkdatabox_bars.h>
+#include <gtkdatabox_offset_bars.h>
+#include <gtkdatabox_regions.h>
 #include <gtkdatabox_cross_simple.h>
 #include <gtkdatabox_ruler.h>
 #include <math.h>
@@ -30,6 +32,8 @@
 #define POINTS 2000
 #define STEPS 50
 #define BARS 25
+#define OFFSET_BARS 25
+#define REGIONS 25
 #define MARKER 10
 
 /*----------------------------------------------------------------
@@ -45,7 +49,7 @@ create_basics (void)
    GtkWidget *box;
    GtkWidget *label;
    GtkWidget *separator;
-   GtkWidget *table;
+   GtkWidget *grid;
    GtkWidget *scrollbar;
    GtkWidget *ruler;
    GtkDataboxGraph *graph;
@@ -53,77 +57,73 @@ create_basics (void)
    gfloat min_y, max_y;
    gfloat *X;
    gfloat *Y;
+   gfloat *Y1; /*  for the offset bars and regions*/
+   gfloat *Y2; /* for the offset bars and regions */
    gfloat buffer;
-   GdkColor color;
+   GdkRGBA color;
    gint i;
 
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_set_size_request (window, 500, 500);
 
-   g_signal_connect (GTK_OBJECT (window), "destroy",
+   g_signal_connect (G_OBJECT (window), "destroy",
 		     G_CALLBACK (gtk_main_quit), NULL);
 
    gtk_window_set_title (GTK_WINDOW (window), "GtkDatabox: Basics");
    gtk_container_set_border_width (GTK_CONTAINER (window), 0);
 
-   vbox = gtk_vbox_new (FALSE, 0);
+   vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
    gtk_container_add (GTK_CONTAINER (window), vbox);
 
    label =
       gtk_label_new
       ("\nThe code for this example demonstrates\n the the basic use of elementary functions\nfor utilizing the GtkDatabox widget.\n\nUsage:\nDraw a selection with the left button pressed,\nThan click into the selection.\nUse the right mouse button to zoom out.\nShift+ right mouse button zooms to default.");
    gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-   separator = gtk_hseparator_new ();
+   separator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
    gtk_box_pack_start (GTK_BOX (vbox), separator, FALSE, FALSE, 0);
 
 
-   /* Instead of the following stuff, you could also call 
+   /* Instead of the following stuff, you could also call
     * gtk_databox_create_box_with_scrollbars_and_rulers
     * as it is done in the other examples.
-    * Of course, you are more flexible in using scrollbars and rulers 
+    * Of course, you are more flexible in using scrollbars and rulers
     * by doing it yourself. */
-   table = gtk_table_new (3, 3, FALSE);
-   box = gtk_databox_new ();
-   gtk_table_attach (GTK_TABLE (table), box, 1, 2, 1, 2,
-		     GTK_FILL | GTK_EXPAND | GTK_SHRINK,
-		     GTK_FILL | GTK_EXPAND | GTK_SHRINK, 0, 0);
+   grid = gtk_grid_new ();
 
-   /* You can associate a scrollbar with a GtkDatabox widget either 
+   box = gtk_databox_new ();
+
+   g_object_set(G_OBJECT(box), "expand", TRUE, NULL);
+
+   gtk_grid_attach (GTK_GRID (grid), box, 1, 1, 1, 1);
+
+   /* You can associate a scrollbar with a GtkDatabox widget either
     * this way ...*/
-   scrollbar = gtk_hscrollbar_new (NULL);
+   scrollbar = gtk_scrollbar_new (GTK_ORIENTATION_HORIZONTAL, NULL);
    gtk_databox_set_adjustment_x (GTK_DATABOX (box),
 				gtk_range_get_adjustment (GTK_RANGE
 							  (scrollbar)));
-   gtk_table_attach (GTK_TABLE (table), scrollbar, 1, 2, 2, 3,
-		     GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL, 0, 0);
+   gtk_grid_attach (GTK_GRID (grid), scrollbar, 1, 2, 1, 1);
    /* or this way ... */
-   scrollbar = gtk_vscrollbar_new
-      (gtk_databox_get_adjustment_y (GTK_DATABOX (box)));
-   gtk_table_attach (GTK_TABLE (table), scrollbar, 2, 3, 1, 2,
-		     GTK_FILL, GTK_FILL | GTK_EXPAND | GTK_SHRINK, 0, 0);
+   scrollbar = gtk_scrollbar_new(GTK_ORIENTATION_VERTICAL,
+      (gtk_databox_get_adjustment_y (GTK_DATABOX (box))));
+   gtk_grid_attach (GTK_GRID (grid), scrollbar, 2, 1, 1, 1);
 
 
    ruler = gtk_databox_ruler_new (GTK_ORIENTATION_HORIZONTAL);
    gtk_widget_set_sensitive (ruler, FALSE);
 
-   gtk_table_attach (GTK_TABLE (table), ruler, 1, 2, 0, 1,
-		     GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL, 0, 0);
+   gtk_grid_attach (GTK_GRID (grid), ruler, 1, 0, 1, 1);
    gtk_databox_set_ruler_x (GTK_DATABOX (box), GTK_DATABOX_RULER (ruler));
 
    ruler = gtk_databox_ruler_new (GTK_ORIENTATION_VERTICAL);
    gtk_widget_set_sensitive (ruler, FALSE);
-   gtk_table_attach (GTK_TABLE (table), ruler, 0, 1, 1, 2,
-		     GTK_FILL, GTK_FILL | GTK_EXPAND | GTK_SHRINK, 0, 0);
+   gtk_grid_attach (GTK_GRID (grid), ruler, 0, 1, 1, 1);
    gtk_databox_set_ruler_y (GTK_DATABOX (box), GTK_DATABOX_RULER (ruler));
    /* end of gtk_databox_create_box_with_scrollbars_and_rulers */
 
-   gtk_box_pack_start (GTK_BOX (vbox), table, TRUE, TRUE, 0);
-
-   color.red = 16383;
-   color.green = 16383;
-   color.blue = 16383;
-   gtk_widget_modify_bg (box, GTK_STATE_NORMAL, &color);
+   gtk_box_pack_start (GTK_BOX (vbox), grid, TRUE, TRUE, 0);
 
+   gtk_databox_set_bg_color (GTK_DATABOX (box), "#333333");
 
    X = g_new0 (gfloat, POINTS);
    Y = g_new0 (gfloat, POINTS);
@@ -134,8 +134,9 @@ create_basics (void)
       Y[i] = 100. * sin (i * 2 * G_PI / POINTS);
    }
    color.red = 0;
-   color.green = 65535;
+   color.green = 1;
    color.blue = 0;
+   color.alpha = 1;
 
    graph = gtk_databox_points_new (POINTS, X, Y, &color, 1);
    gtk_databox_graph_add (GTK_DATABOX (box), graph);
@@ -153,9 +154,10 @@ create_basics (void)
       if (i == STEPS / 2 - 1)
 	 Y[i * 2 + 1] = 100. * sin (((i + 1) * 2) * 2 * G_PI / STEPS);
    }
-   color.red = 65535;
+   color.red = 1;
    color.green = 0;
    color.blue = 0;
+   color.alpha = 1;
 
    graph = gtk_databox_lines_new (STEPS, X, Y, &color, 1);
    gtk_databox_graph_add (GTK_DATABOX (box), graph);
@@ -168,24 +170,63 @@ create_basics (void)
       X[i] = i * POINTS / BARS;
       Y[i] = 80. * sin (i * 2 * G_PI / BARS);
    }
+
    color.red = 0;
-   color.green = 65535;
-   color.blue = 65535;
+   color.green = 1;
+   color.blue = 1;
+   color.alpha = 1;
 
    graph = gtk_databox_bars_new (BARS, X, Y, &color, 1);
    gtk_databox_graph_add (GTK_DATABOX (box), graph);
 
-   color.red = 32768;
-   color.green = 32768;
-   color.blue = 32768;
+   color.red = 0.5;
+   color.green = 0.5;
+   color.blue = 0.5;
+   color.alpha = 1;
 
    graph = gtk_databox_cross_simple_new (&color, 0);
    gtk_databox_graph_add (GTK_DATABOX (box), graph);
 
-   /* Instead of doing stuff what you see below, you could call 
+   X = g_new0 (gfloat, OFFSET_BARS);
+   Y1 = g_new0 (gfloat, OFFSET_BARS);
+   Y2 = g_new0 (gfloat, OFFSET_BARS);
+
+   for (i = 0; i < OFFSET_BARS; i++)
+   {
+      X[i] = (i+0.5) * POINTS / OFFSET_BARS;
+      Y1[i] = 80. * sin ((i+0.5) * 2 * G_PI / OFFSET_BARS);
+      Y2[i] = -0.5*(80. * sin ((i+0.5) * 2 * G_PI / OFFSET_BARS));
+   }
+   color.red = 1;
+   color.green = 0;
+   color.blue = 1;
+   color.alpha = 1;
+
+   graph = gtk_databox_offset_bars_new (BARS, X, Y1, Y2, &color, 1);
+   gtk_databox_graph_add (GTK_DATABOX (box), graph);
+
+   X = g_new0 (gfloat, REGIONS);
+   Y1 = g_new0 (gfloat, REGIONS);
+   Y2 = g_new0 (gfloat, REGIONS);
+
+   for (i = 0; i < REGIONS; i++)
+   {
+      X[i] = (i+0.5) * POINTS / REGIONS;
+      Y1[i] = .5*80. * sin ((i+0.5) * 2 * G_PI / REGIONS);
+      Y2[i] = .5*-0.5*(80. * sin ((i+0.5) * 2 * G_PI / REGIONS));
+   }
+   color.red = 0.5;
+   color.green = 0.25;
+   color.blue = 0.5;
+   color.alpha = 1;
+
+   graph = gtk_databox_regions_new (BARS, X, Y1, Y2, &color);
+   gtk_databox_graph_add (GTK_DATABOX (box), graph);
+
+   /* Instead of doing stuff what you see below, you could call
     * gtk_databox_auto_rescale (GTK_DATABOX (box), 0.05);
-    * as is done in the other examples 
-    * Of course, you are more flexible in adjusting the scaling by doing 
+    * as is done in the other examples
+    * Of course, you are more flexible in adjusting the scaling by doing
     * it yourself, though. */
    if (0 >
        gtk_databox_calculate_extrema (GTK_DATABOX (box), &min_x, &max_x,
@@ -218,19 +259,19 @@ create_basics (void)
 				 max_y);
    /* end of gtk_databox_auto_rescale */
 
-   separator = gtk_hseparator_new ();
+   separator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
    gtk_box_pack_start (GTK_BOX (vbox), separator, FALSE, TRUE, 0);
 
    close_button = gtk_button_new_with_label ("close");
-   g_signal_connect_swapped (GTK_OBJECT (close_button), "clicked",
-			     G_CALLBACK (gtk_main_quit), GTK_OBJECT (box));
+   g_signal_connect_swapped (G_OBJECT (close_button), "clicked",
+			     G_CALLBACK (gtk_main_quit), G_OBJECT (box));
    gtk_box_pack_start (GTK_BOX (vbox), close_button, FALSE, FALSE, 0);
-   GTK_WIDGET_SET_FLAGS (close_button, GTK_CAN_DEFAULT);
+   gtk_widget_set_can_default(close_button, TRUE);
    gtk_widget_grab_default (close_button);
    gtk_widget_grab_focus (close_button);
 
    gtk_widget_show_all (window);
-   gdk_window_set_cursor (box->window, gdk_cursor_new (GDK_CROSS));
+   gdk_window_set_cursor (gtk_widget_get_window(box), gdk_cursor_new_for_display (gdk_display_get_default (), GDK_CROSS));
 }
 
 gint
