@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 #include <stdio.h>
 
@@ -84,32 +84,32 @@ create_show_hide (void)
    GtkDataboxGraph *graph;
    gfloat *X;
    gfloat *Y;
-   GdkColor color;
+   GdkRGBA color;
    gint i;
 
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_set_size_request (window, 600, 600);
 
-   g_signal_connect (GTK_OBJECT (window), "destroy",
+   g_signal_connect (G_OBJECT (window), "destroy",
 		     G_CALLBACK (gtk_main_quit), NULL);
 
    gtk_window_set_title (GTK_WINDOW (window),
 			 "GtkDatabox: Enable/Disable Features");
    gtk_container_set_border_width (GTK_CONTAINER (window), 0);
 
-   box1 = gtk_vbox_new (FALSE, 0);
+   box1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
    gtk_container_add (GTK_CONTAINER (window), box1);
 
    label =
       gtk_label_new
       ("Click on the buttons to enable/disable features.\n\nFor basic understanding: See basics :-)\n\n");
    gtk_box_pack_start (GTK_BOX (box1), label, FALSE, FALSE, 0);
-   separator = gtk_hseparator_new ();
+   separator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
    gtk_box_pack_start (GTK_BOX (box1), separator, FALSE, FALSE, 0);
 
-   enable_box = gtk_hbox_new (FALSE, 0);
+   enable_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
    gtk_box_pack_start (GTK_BOX (box1), enable_box, FALSE, FALSE, 0);
-   separator = gtk_hseparator_new ();
+   separator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
    gtk_box_pack_start (GTK_BOX (box1), separator, FALSE, FALSE, 0);
 
    /* Create a GtkDatabox widget along with scrollbars and rulers */
@@ -128,27 +128,28 @@ create_show_hide (void)
    }
    color.red = 0;
    color.green = 0;
-   color.blue = 65535;
+   color.blue = 1;
+   color.alpha = 1;
 
    graph = gtk_databox_bars_new (POINTS, X, Y, &color, 1);
    gtk_databox_graph_add (GTK_DATABOX (box), graph);
 
    gtk_databox_auto_rescale (GTK_DATABOX (box), 0.05);
 
-   separator = gtk_hseparator_new ();
+   separator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
    gtk_box_pack_start (GTK_BOX (box1), separator, FALSE, TRUE, 0);
 
-   box2 = gtk_vbox_new (FALSE, 10);
+   box2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 10);
    gtk_container_set_border_width (GTK_CONTAINER (box2), 10);
    gtk_box_pack_end (GTK_BOX (box1), box2, FALSE, TRUE, 0);
    close_button = gtk_button_new_with_label ("close");
-   g_signal_connect_swapped (GTK_OBJECT (close_button), "clicked",
-			     G_CALLBACK (gtk_main_quit), GTK_OBJECT (box));
+   g_signal_connect_swapped (G_OBJECT (close_button), "clicked",
+			     G_CALLBACK (gtk_main_quit), G_OBJECT (box));
    gtk_box_pack_start (GTK_BOX (box2), close_button, TRUE, TRUE, 0);
-   GTK_WIDGET_SET_FLAGS (close_button, GTK_CAN_DEFAULT);
+   gtk_widget_set_can_default(close_button, TRUE);
    for (i = 0; i < noEnableSets; ++i)
    {
-      GtkWidget *vbox = gtk_vbox_new (FALSE, 10);
+      GtkWidget *vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 10);
       GtkWidget *label = gtk_label_new (enableSets[i].title);
       GtkWidget *entry = gtk_entry_new ();
       GtkWidget *button = gtk_button_new_with_label ("Change");
