@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 #include <stdio.h>
 
@@ -25,6 +25,7 @@
 #include <math.h>
 
 #define POINTS 2000
+#define FRAME_RATE 50
 
 /*----------------------------------------------------------------
  *  databox lissajous
@@ -33,13 +34,13 @@
 static gfloat *lissajousX = NULL;
 static gfloat *lissajousY = NULL;
 
-static gint lissajous_idle = 0;
-static gfloat lissajous_frequency = 3. * G_PI / 2.;
-static GtkWidget *lissajous_label = NULL;
-static guint lissajous_counter = 0;
+static gint lissajous_timeout_id;
+static gfloat lissajous_frequency;
+static GtkWidget *lissajous_label;
+static guint lissajous_counter;
 
 static gboolean
-lissajous_idle_func (GtkDatabox * box)
+lissajous_draw_func (GtkDatabox * box)
 {
    gfloat freq;
    gfloat off;
@@ -49,7 +50,7 @@ lissajous_idle_func (GtkDatabox * box)
    if (!GTK_IS_DATABOX (box))
       return FALSE;
 
-   lissajous_frequency += 0.001;
+   lissajous_frequency += 0.025;
    off = lissajous_counter * 4 * G_PI / POINTS;
 
    freq = 14 + 10 * sin (lissajous_frequency);
@@ -80,10 +81,9 @@ create_lissajous (void)
    GtkWidget *table;
    GtkWidget *separator;
    GtkDataboxGraph *graph;
-   GdkColor color;
+   GdkRGBA color;
    gint i;
 
-   lissajous_frequency = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_set_size_request (window, 500, 500);
 
@@ -94,22 +94,22 @@ create_lissajous (void)
 			 "GtkDatabox: Lissajous Example");
    gtk_container_set_border_width (GTK_CONTAINER (window), 0);
 
-   box1 = gtk_vbox_new (FALSE, 0);
+   box1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
    gtk_container_add (GTK_CONTAINER (window), box1);
 
    label =
       gtk_label_new
-      ("This example resembles an oszilloscope\nreceiving two signals, one is a sine (horizontal),\nthe other is a cosine with ever changing frequency (vertical).\nThe counter is synchron with the updates.");
+      ("This example resembles an oscilloscope\nreceiving two signals, one is a sine (horizontal),\nthe other is a cosine with ever changing frequency (vertical).\nThe counter is synchron with the updates.");
    gtk_box_pack_start (GTK_BOX (box1), label, FALSE, FALSE, 0);
-   separator = gtk_hseparator_new ();
+   separator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
    gtk_box_pack_start (GTK_BOX (box1), separator, FALSE, FALSE, 0);
    lissajous_label = gtk_entry_new ();
    gtk_entry_set_text (GTK_ENTRY (lissajous_label), "0");
    gtk_box_pack_start (GTK_BOX (box1), lissajous_label, FALSE, FALSE, 0);
-   separator = gtk_hseparator_new ();
+   separator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
    gtk_box_pack_start (GTK_BOX (box1), separator, FALSE, FALSE, 0);
 
-   lissajous_idle = 0;
+   lissajous_timeout_id = 0;
    lissajous_frequency = 3. * G_PI / 2.;
    lissajous_counter = 0;
 
@@ -117,13 +117,11 @@ create_lissajous (void)
    gtk_databox_create_box_with_scrollbars_and_rulers (&box, &table,
 						      TRUE, TRUE, TRUE, TRUE);
 
+   g_object_set(G_OBJECT(box), "expand", TRUE, NULL);
+
    gtk_box_pack_start (GTK_BOX (box1), table, TRUE, TRUE, 0);
 
-   color.red = 0;
-   color.green = 0;
-   color.blue = 32768;
-
-   gtk_widget_modify_bg (box, GTK_STATE_NORMAL, &color);
+   gtk_databox_set_bg_color (GTK_DATABOX (box), "#008");
 
    lissajousX = g_new0 (gfloat, POINTS);
    lissajousY = g_new0 (gfloat, POINTS);
@@ -133,19 +131,20 @@ create_lissajous (void)
       lissajousX[i] = 100. * sin (i * 4 * G_PI / POINTS);
       lissajousY[i] = 100. * cos (i * 4 * G_PI / POINTS);
    }
-   color.red = 65535;
-   color.green = 65535;
+   color.red = 1;
+   color.green = 1;
    color.blue = 0;
+   color.alpha = 1;
 
    graph = gtk_databox_lines_new (POINTS, lissajousX, lissajousY, &color, 1);
    gtk_databox_graph_add (GTK_DATABOX (box), graph);
 
    gtk_databox_auto_rescale (GTK_DATABOX (box), 0.05);
 
-   separator = gtk_hseparator_new ();
+   separator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
    gtk_box_pack_start (GTK_BOX (box1), separator, FALSE, TRUE, 0);
 
-   box2 = gtk_vbox_new (FALSE, 10);
+   box2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 10);
    gtk_container_set_border_width (GTK_CONTAINER (box2), 10);
    gtk_box_pack_end (GTK_BOX (box1), box2, FALSE, TRUE, 0);
    close_button = gtk_button_new_with_label ("close");
@@ -154,9 +153,10 @@ create_lissajous (void)
 			     G_CALLBACK (gtk_main_quit), G_OBJECT (box));
 
    gtk_box_pack_start (GTK_BOX (box2), close_button, TRUE, TRUE, 0);
-   gtk_widget_set_can_default(close_button, GTK_CAN_DEFAULT);
+   gtk_widget_set_can_default(close_button, TRUE);
    gtk_widget_grab_default (close_button);
-   lissajous_idle = g_idle_add ((GSourceFunc) lissajous_idle_func, box);
+   lissajous_timeout_id = g_timeout_add (1000 / FRAME_RATE,
+               (GSourceFunc) lissajous_draw_func, box);
 
    gtk_widget_show_all (window);
 }
