@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 #include <stdio.h>
 
@@ -25,10 +25,12 @@
 #include <math.h>
 
 #define POINTS 100000
+/*
 #define STEPS 50
 #define BARS 25
 #define MARKER 10
-#define NO_BOXES 3
+*/
+#define NO_BOXES 4
 
 /*----------------------------------------------------------------
  *  databox logarithmic
@@ -46,33 +48,34 @@ create_logarithmic (void)
    GtkWidget *separator;
    GtkWidget *table;
    GtkDataboxGraph *graph;
+   GdkCursor *cursor;
    gfloat min_x, max_x;
    gfloat min_y, max_y;
    gfloat *X;
    gfloat *Y;
-   GdkColor color;
+   GdkRGBA color;
    gint i;
 
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_set_size_request (window, 1000, 500);
 
-   g_signal_connect (GTK_OBJECT (window), "destroy",
+   g_signal_connect (G_OBJECT (window), "destroy",
 		     G_CALLBACK (gtk_main_quit), NULL);
 
    gtk_window_set_title (GTK_WINDOW (window),
 			 "GtkDatabox: Logarithmic Plots");
    gtk_container_set_border_width (GTK_CONTAINER (window), 0);
 
-   vbox = gtk_vbox_new (FALSE, 0);
+   vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
    gtk_container_add (GTK_CONTAINER (window), vbox);
 
    label = gtk_label_new
       ("The following types of curves are shown (with some adjustments to make them fit nicely into the window):\n Green: sin^2, Red: exp, Magenta: 1/x, Yellow: x^2\n(100K Points per each curve in each graph)\n");
    gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-   separator = gtk_hseparator_new ();
+   separator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
    gtk_box_pack_start (GTK_BOX (vbox), separator, FALSE, FALSE, 0);
 
-   hbox = gtk_hbox_new (FALSE, 0);
+   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
    label = gtk_label_new ("Linear Plot:");
@@ -84,11 +87,14 @@ create_logarithmic (void)
    label = gtk_label_new ("Double Logarithmic Plot:");
    gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 
-   separator = gtk_hseparator_new ();
+   label = gtk_label_new ("Log base 2 Plot:");
+   gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
+
+   separator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
    gtk_box_pack_start (GTK_BOX (vbox), separator, FALSE, FALSE, 0);
 
    /* Create the databoxes */
-   hbox = gtk_hbox_new (FALSE, 0);
+   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
    gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
 
    for (i = 0; i < NO_BOXES; ++i)
@@ -100,11 +106,8 @@ create_logarithmic (void)
    }
 
    /* set the background */
-   color.red = 16383;
-   color.green = 16383;
-   color.blue = 16383;
    for (i = 0; i < NO_BOXES; ++i)
-      gtk_widget_modify_bg (box[i], GTK_STATE_NORMAL, &color);
+      gtk_databox_set_bg_color (GTK_DATABOX (box[i]), "#545454");
 
    /* add a sinus^2 */
    X = g_new0 (gfloat, POINTS);
@@ -117,8 +120,9 @@ create_logarithmic (void)
    }
 
    color.red = 0;
-   color.green = 65535;
+   color.green = 1;
    color.blue = 0;
+   color.alpha = 1;
 
    graph = gtk_databox_points_new (POINTS, X, Y, &color, 1);
    for (i = 0; i < NO_BOXES; ++i)
@@ -134,9 +138,10 @@ create_logarithmic (void)
       Y[i] = exp (log (1000) * i / ((gfloat) POINTS));
    }
 
-   color.red = 65535;
+   color.red = 1;
    color.green = 0;
    color.blue = 0;
+   color.alpha = 1;
 
    graph = gtk_databox_points_new (POINTS, X, Y, &color, 1);
    for (i = 0; i < NO_BOXES; ++i)
@@ -152,9 +157,10 @@ create_logarithmic (void)
       Y[i] = 1000. / (100. * (gfloat) i / POINTS);
    }
 
-   color.red = 65535;
+   color.red = 1;
    color.green = 0;
-   color.blue = 65535;
+   color.blue = 1;
+   color.alpha = 1;
 
    graph = gtk_databox_points_new (POINTS, X, Y, &color, 1);
    for (i = 0; i < NO_BOXES; ++i)
@@ -170,9 +176,10 @@ create_logarithmic (void)
       Y[i] = 1000. * (gfloat) i / POINTS * (gfloat) i / POINTS;
    }
 
-   color.red = 65535;
-   color.green = 65535;
+   color.red = 1;
+   color.green = 1;
    color.blue = 0;
+   color.alpha = 1;
 
    graph = gtk_databox_points_new (POINTS, X, Y, &color, 1);
    for (i = 0; i < NO_BOXES; ++i)
@@ -184,27 +191,34 @@ create_logarithmic (void)
    min_y = 1000.;
    max_y = 0.01;
 
-   for (i = 0; i < NO_BOXES; ++i)
+   for (i = 0; i < NO_BOXES-1; ++i)
+   {
       gtk_databox_set_total_limits (GTK_DATABOX (box[i]), min_x, max_x, min_y,
 				    max_y);
+   }
+   gtk_databox_set_total_limits (GTK_DATABOX (box[i]), 8, max_x, min_y,
+				    max_y);
 
    gtk_databox_set_scale_type_y (GTK_DATABOX (box[1]), GTK_DATABOX_SCALE_LOG);
    gtk_databox_set_scale_type_x (GTK_DATABOX (box[2]), GTK_DATABOX_SCALE_LOG);
    gtk_databox_set_scale_type_y (GTK_DATABOX (box[2]), GTK_DATABOX_SCALE_LOG);
+   gtk_databox_set_scale_type_x (GTK_DATABOX (box[3]), GTK_DATABOX_SCALE_LOG2);
 
-   separator = gtk_hseparator_new ();
+   separator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
    gtk_box_pack_start (GTK_BOX (vbox), separator, FALSE, TRUE, 0);
 
    close_button = gtk_button_new_with_label ("close");
-   g_signal_connect (GTK_OBJECT (close_button), "clicked",
+   g_signal_connect (G_OBJECT (close_button), "clicked",
 		     G_CALLBACK (gtk_main_quit), NULL);
    gtk_box_pack_start (GTK_BOX (vbox), close_button, FALSE, FALSE, 0);
-   GTK_WIDGET_SET_FLAGS (close_button, GTK_CAN_DEFAULT);
+   gtk_widget_set_can_default(close_button, TRUE);
    gtk_widget_grab_default (close_button);
    gtk_widget_grab_focus (close_button);
 
    gtk_widget_show_all (window);
-   gdk_window_set_cursor (box[0]->window, gdk_cursor_new (GDK_CROSS));
+   cursor = gdk_cursor_new_for_display (gdk_display_get_default (), GDK_CROSS);
+   for (i = 0; i < NO_BOXES; ++i)
+      gdk_window_set_cursor (gtk_widget_get_window(box[i]), cursor);
 }
 
 gint
