@@ -1,5 +1,6 @@
+/* $Id: gtkdatabox_cross_simple.c 4 2008-06-22 09:19:11Z rbock $ */
 /* GtkDatabox - An extension to the gtk+ library
- * Copyright (C) 1998 - 2007  Dr. Roland Bock
+ * Copyright (C) 1998 - 2008  Dr. Roland Bock
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -13,20 +14,18 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include <gtkdatabox_cross_simple.h>
 
-static gpointer parent_class = NULL;
+G_DEFINE_TYPE(GtkDataboxCrossSimple, gtk_databox_cross_simple,
+	GTK_DATABOX_TYPE_MARKERS)
 
 static void
 cross_simple_finalize (GObject * object)
 {
    gpointer pointer;
-   GtkDataboxCrossSimple *cross_simple = GTK_DATABOX_CROSS_SIMPLE (object);
-
-   g_free (cross_simple->priv);
 
    pointer = gtk_databox_xyc_graph_get_X (GTK_DATABOX_XYC_GRAPH (object));
    if (pointer)
@@ -37,46 +36,20 @@ cross_simple_finalize (GObject * object)
       g_free (pointer);
 
    /* Chain up to the parent class */
-   G_OBJECT_CLASS (parent_class)->finalize (object);
+   G_OBJECT_CLASS (gtk_databox_cross_simple_parent_class)->finalize (object);
 }
 
 static void
-gtk_databox_cross_simple_class_init (gpointer g_class
-				     /*, gpointer g_class_data */ )
+gtk_databox_cross_simple_class_init (GtkDataboxCrossSimpleClass *klass)
 {
-   GObjectClass *gobject_class = G_OBJECT_CLASS (g_class);
-   GtkDataboxCrossSimpleClass *klass =
-      GTK_DATABOX_CROSS_SIMPLE_CLASS (g_class);
-
-   parent_class = g_type_class_peek_parent (klass);
+   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
    gobject_class->finalize = cross_simple_finalize;
 }
 
-GType
-gtk_databox_cross_simple_get_type (void)
+static void gtk_databox_cross_simple_init(GtkDataboxCrossSimple *cross) 
 {
-   static GType type = 0;
-
-   if (type == 0)
-   {
-      static const GTypeInfo info = {
-	 sizeof (GtkDataboxCrossSimpleClass),
-	 NULL,			/* base_init */
-	 NULL,			/* base_finalize */
-	 (GClassInitFunc) gtk_databox_cross_simple_class_init,	/* class_init */
-	 NULL,			/* class_finalize */
-	 NULL,			/* class_data */
-	 sizeof (GtkDataboxCrossSimple),	/* instance_size */
-	 0,			/* n_preallocs */
-	 NULL,			/* instance_init */
-	 NULL,			/* value_table */
-      };
-      type = g_type_register_static (GTK_DATABOX_TYPE_MARKERS,
-				     "GtkDataboxCrossSimple", &info, 0);
-   }
-
-   return type;
+   if (cross == NULL) g_warning ("cross_simple_init with NULL");
 }
 
 /**
@@ -89,7 +62,7 @@ gtk_databox_cross_simple_get_type (void)
  * Return value: A new #GtkDataboxCrossSimple object
  **/
 GtkDataboxGraph *
-gtk_databox_cross_simple_new (GdkColor * color, guint size)
+gtk_databox_cross_simple_new (GdkRGBA * color, guint size)
 {
    GtkDataboxCrossSimple *cross_simple;
    gfloat *X = g_new0 (gfloat, 2);
@@ -100,7 +73,14 @@ gtk_databox_cross_simple_new (GdkColor * color, guint size)
 				"markers-type", GTK_DATABOX_MARKERS_SOLID_LINE,
 				"X-Values", X,
 				"Y-Values", Y,
+			 	"xstart", 0,
+			 	"ystart", 0,
+			 	"xstride", 1,
+			 	"ystride", 1,
+			 	"xtype", G_TYPE_FLOAT,
+			 	"ytype", G_TYPE_FLOAT,
 				"length", len,
+				"maxlen", len,
 				"color", color, "size", size, NULL);
 
    gtk_databox_markers_set_position (GTK_DATABOX_MARKERS (cross_simple), 0,
