@@ -1,5 +1,6 @@
+/* $Id: gtkdatabox_markers.c 4 2008-06-22 09:19:11Z rbock $ */
 /* GtkDatabox - An extension to the gtk+ library
- * Copyright (C) 1998 - 2007  Dr. Roland Bock
+ * Copyright (C) 1998 - 2008  Dr. Roland Bock
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -13,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include <gtkdatabox_markers.h>
@@ -21,7 +22,7 @@
 
 static void gtk_databox_markers_real_draw (GtkDataboxGraph * markers,
 					  GtkDatabox* box);
-static GdkGC* gtk_databox_markers_real_create_gc (GtkDataboxGraph * graph,
+static cairo_t* gtk_databox_markers_real_create_gc (GtkDataboxGraph * graph,
 					       GtkDatabox* box);
 
 /* IDs of properties */
@@ -41,21 +42,33 @@ typedef struct
 }
 GtkDataboxMarkersInfo;
 
+/**
+ * GtkDataboxMarkersPrivate:
+ *
+ * A private data structure used by the #GtkDataboxMarkers. It shields all internal things
+ * from developers who are just using the object.
+ *
+ **/
+typedef struct _GtkDataboxMarkersPrivate GtkDataboxMarkersPrivate;
+
 struct _GtkDataboxMarkersPrivate
 {
    GtkDataboxMarkersType type;
    GtkDataboxMarkersInfo *markers_info;
-   GdkGC *label_gc;
+   gint16 *xpixels;
+   gint16 *ypixels;
+   guint pixelsalloc;
 };
 
-static gpointer parent_class = NULL;
+G_DEFINE_TYPE_WITH_PRIVATE(GtkDataboxMarkers, gtk_databox_markers,
+	GTK_DATABOX_TYPE_XYC_GRAPH)
 
 static void
 gtk_databox_markers_set_mtype (GtkDataboxMarkers * markers, gint type)
 {
    g_return_if_fail (GTK_DATABOX_IS_MARKERS (markers));
-
-   markers->priv->type = type;
+   GtkDataboxMarkersPrivate *priv = gtk_databox_markers_get_instance_private (markers);
+   priv->type = type;
 
    g_object_notify (G_OBJECT (markers), "markers-type");
 }
@@ -85,8 +98,8 @@ static gint
 gtk_databox_markers_get_mtype (GtkDataboxMarkers * markers)
 {
    g_return_val_if_fail (GTK_DATABOX_IS_MARKERS (markers), 0);
-
-   return markers->priv->type;
+   GtkDataboxMarkersPrivate *priv = gtk_databox_markers_get_instance_private (markers);
+   return priv->type;
 }
 
 static void
@@ -114,6 +127,7 @@ static void
 markers_finalize (GObject * object)
 {
    GtkDataboxMarkers *markers = GTK_DATABOX_MARKERS (object);
+   GtkDataboxMarkersPrivate *priv = gtk_databox_markers_get_instance_private (markers);
    int i;
    int len;
 
@@ -121,64 +135,48 @@ markers_finalize (GObject * object)
 
    for (i = 0; i < len; ++i)
    {
-      if (markers->priv->markers_info[i].label)
-	 g_object_unref (markers->priv->markers_info[i].label);
-      if (markers->priv->markers_info[i].text)
-	 g_free (markers->priv->markers_info[i].text);
+      if (priv->markers_info[i].label)
+	 g_object_unref (priv->markers_info[i].label);
+      if (priv->markers_info[i].text)
+	 g_free (priv->markers_info[i].text);
    }
-   g_free (markers->priv->markers_info);
-   g_free (markers->priv);
+   g_free (priv->markers_info);
+   g_free (priv->xpixels);
+   g_free (priv->ypixels);
 
    /* Chain up to the parent class */
-   G_OBJECT_CLASS (parent_class)->finalize (object);
+   G_OBJECT_CLASS (gtk_databox_markers_parent_class)->finalize (object);
 }
 
-static GdkGC *
+static cairo_t *
 gtk_databox_markers_real_create_gc (GtkDataboxGraph * graph,
 				   GtkDatabox* box)
 {
    GtkDataboxMarkers *markers = GTK_DATABOX_MARKERS (graph);
-   GdkGC *gc;
-   GdkGCValues values;
+   GtkDataboxMarkersPrivate *priv = gtk_databox_markers_get_instance_private (markers);
+   cairo_t *cr;
+   static const double dash = 5.0f;
 
    g_return_val_if_fail (GTK_DATABOX_IS_MARKERS (graph), NULL);
 
-   gc = GTK_DATABOX_GRAPH_CLASS (parent_class)->create_gc (graph, box);
+   cr = GTK_DATABOX_GRAPH_CLASS (gtk_databox_markers_parent_class)->create_gc (graph, box);
 
-   if (gc)
+   if (cr)
    {
-      if (markers->priv->type == GTK_DATABOX_MARKERS_DASHED_LINE)
-      {
-         values.line_style = GDK_LINE_ON_OFF_DASH;
-         values.cap_style = GDK_CAP_BUTT;
-         values.join_style = GDK_JOIN_MITER;
-         gdk_gc_set_values (gc, &values,
-			    GDK_GC_LINE_STYLE |
-			    GDK_GC_CAP_STYLE | GDK_GC_JOIN_STYLE);
-      }
-   
-      if (markers->priv->label_gc)
-         g_object_unref (markers->priv->label_gc);
-   
-      markers->priv->label_gc = gdk_gc_new (gtk_databox_get_backing_pixmap (box));
-      gdk_gc_copy (markers->priv->label_gc, gc);
-      gdk_gc_set_line_attributes (markers->priv->label_gc, 1,
-			          GDK_LINE_SOLID, GDK_CAP_ROUND, GDK_JOIN_ROUND);
+      if (priv->type == GTK_DATABOX_MARKERS_DASHED_LINE)
+         cairo_set_dash (cr, &dash, 1, 0.0);
    }
 
-   return gc;
+   return cr;
 }
 
 static void
-gtk_databox_markers_class_init (gpointer g_class /*, gpointer g_class_data */ )
+gtk_databox_markers_class_init (GtkDataboxMarkersClass *klass)
 {
-   GObjectClass *gobject_class = G_OBJECT_CLASS (g_class);
-   GtkDataboxGraphClass *graph_class = GTK_DATABOX_GRAPH_CLASS (g_class);
-   GtkDataboxMarkersClass *klass = GTK_DATABOX_MARKERS_CLASS (g_class);
+   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
+   GtkDataboxGraphClass *graph_class = GTK_DATABOX_GRAPH_CLASS (klass);
    GParamSpec *markers_param_spec;
 
-   parent_class = g_type_class_peek_parent (klass);
-
    gobject_class->set_property = gtk_databox_markers_set_property;
    gobject_class->get_property = gtk_databox_markers_get_property;
    gobject_class->finalize = markers_finalize;
@@ -196,7 +194,8 @@ gtk_databox_markers_class_init (gpointer g_class /*, gpointer g_class_data */ )
 static void
 complete (GtkDataboxMarkers * markers)
 {
-   markers->priv->markers_info =
+   GtkDataboxMarkersPrivate *priv = gtk_databox_markers_get_instance_private (markers);
+   priv->markers_info =
       g_new0 (GtkDataboxMarkersInfo,
 	      gtk_databox_xyc_graph_get_length
 	      (GTK_DATABOX_XYC_GRAPH (markers)));
@@ -204,42 +203,17 @@ complete (GtkDataboxMarkers * markers)
 }
 
 static void
-gtk_databox_markers_instance_init (GTypeInstance * instance	/*,
-								   gpointer g_class */ )
+gtk_databox_markers_init (GtkDataboxMarkers *markers)
 {
-   GtkDataboxMarkers *markers = GTK_DATABOX_MARKERS (instance);
-
-   markers->priv = g_new0 (GtkDataboxMarkersPrivate, 1);
+   GtkDataboxMarkersPrivate *priv = gtk_databox_markers_get_instance_private (markers);
+   priv->markers_info = NULL;
+   priv->xpixels = NULL;
+   priv->ypixels = NULL;
+   priv->pixelsalloc = 0;
 
    g_signal_connect (markers, "notify::length", G_CALLBACK (complete), NULL);
 }
 
-GType
-gtk_databox_markers_get_type (void)
-{
-   static GType type = 0;
-
-   if (type == 0)
-   {
-      static const GTypeInfo info = {
-	 sizeof (GtkDataboxMarkersClass),
-	 NULL,			/* base_init */
-	 NULL,			/* base_finalize */
-	 (GClassInitFunc) gtk_databox_markers_class_init,	/* class_init */
-	 NULL,			/* class_finalize */
-	 NULL,			/* class_data */
-	 sizeof (GtkDataboxMarkers),	/* instance_size */
-	 0,			/* n_preallocs */
-	 (GInstanceInitFunc) gtk_databox_markers_instance_init,	/* instance_init */
-	 NULL,			/* value_table */
-      };
-      type = g_type_register_static (GTK_DATABOX_TYPE_XYC_GRAPH,
-				     "GtkDataboxMarkers", &info, 0);
-   }
-
-   return type;
-}
-
 /**
  * gtk_databox_markers_new:
  * @len: length of @X and @Y
@@ -255,7 +229,7 @@ gtk_databox_markers_get_type (void)
  **/
 GtkDataboxGraph *
 gtk_databox_markers_new (guint len, gfloat * X, gfloat * Y,
-			GdkColor * color, guint size,
+			GdkRGBA * color, guint size,
 			GtkDataboxMarkersType type)
 {
    GtkDataboxMarkers *markers;
@@ -266,7 +240,63 @@ gtk_databox_markers_new (guint len, gfloat * X, gfloat * Y,
    markers = g_object_new (GTK_DATABOX_TYPE_MARKERS,
 			  "X-Values", X,
 			  "Y-Values", Y,
+			  "xstart", 0,
+			  "ystart", 0,
+			  "xstride", 1,
+			  "ystride", 1,
+			  "xtype", G_TYPE_FLOAT,
+			  "ytype", G_TYPE_FLOAT,
 			  "length", len,
+			  "maxlen", len,
+			  "color", color,
+			  "size", size, "markers-type", type, NULL);
+
+   return GTK_DATABOX_GRAPH (markers);
+}
+
+/**
+ * gtk_databox_markers_new_full:
+ * @maxlen: maximum length of @X and @Y
+ * @len: actual number of @X and @Y values to plot
+ * @X: array of horizontal position values of markers
+ * @Y: array of vertical position values of markers
+ * @xstart: the first element in the X array to plot (usually 0)
+ * @ystart: the first element in the Y array to plot (usually 0)
+ * @xstride: successive elements in the X array are separated by this much (1 if array, ncols if matrix)
+ * @ystride: successive elements in the Y array are separated by this much (1 if array, ncols if matrix)
+ * @xtype: the GType of the X array elements.  G_TYPE_FLOAT, G_TYPE_DOUBLE, etc.
+ * @ytype: the GType of the Y array elements.  G_TYPE_FLOAT, G_TYPE_DOUBLE, etc.
+ * @color: color of the markers
+ * @size: marker size or line width (depending on the @type)
+ * @type: type of markers (e.g. triangle or circle)
+ *
+ * Creates a new #GtkDataboxMarkers object which can be added to a #GtkDatabox widget as nice decoration for other graphs.
+ *
+ * Return value: A new #GtkDataboxMarkers object
+ **/
+GtkDataboxGraph *
+gtk_databox_markers_new_full (guint maxlen, guint len,
+			void * X, guint xstart, guint xstride, GType xtype,
+			void * Y, guint ystart, guint ystride, GType ytype,
+			GdkRGBA * color, guint size,
+			GtkDataboxMarkersType type)
+{
+   GtkDataboxMarkers *markers;
+   g_return_val_if_fail (X, NULL);
+   g_return_val_if_fail (Y, NULL);
+   g_return_val_if_fail ((len > 0), NULL);
+
+   markers = g_object_new (GTK_DATABOX_TYPE_MARKERS,
+			  "X-Values", X,
+			  "Y-Values", Y,
+			  "xstart", xstart,
+			  "ystart", ystart,
+			  "xstride", xstride,
+			  "ystride", ystride,
+			  "xtype", xtype,
+			  "ytype", ytype,
+			  "length", len,
+			  "maxlen", maxlen,
 			  "color", color,
 			  "size", size, "markers-type", type, NULL);
 
@@ -274,9 +304,8 @@ gtk_databox_markers_new (guint len, gfloat * X, gfloat * Y,
 }
 
 static gint
-gtk_databox_label_write_at (GdkPixmap * pixmap,
+gtk_databox_label_write_at (cairo_t *cr,
 			    PangoLayout * pl,
-			    GdkGC * gc,
 			    GdkPoint coord,
 			    GtkDataboxMarkersTextPosition position,
 			    gint distance, gboolean boxed)
@@ -350,13 +379,19 @@ gtk_databox_label_write_at (GdkPixmap * pixmap,
       vdist_box = vdist_text - offset;
    }
 
-   gdk_draw_layout (pixmap, gc,
-		    coord.x + hdist_text, coord.y + vdist_text, pl);
 
-   if (boxed)
-      gdk_draw_rectangle (pixmap, gc, FALSE,
-			  coord.x + hdist_box,
-			  coord.y + vdist_box, width + 3, height + 3);
+   cairo_move_to(cr, coord.x + hdist_text, coord.y + vdist_text);
+   pango_cairo_show_layout(cr, pl);
+
+   if (boxed) {
+      cairo_save (cr);
+      cairo_set_line_width (cr, 1.0);
+      cairo_set_dash (cr, NULL, 0, 0.0);
+      cairo_rectangle (cr, coord.x + hdist_box - 0.5,
+			  coord.y + vdist_box - 0.5, width + 3.5, height + 3.5);
+	  cairo_stroke(cr);
+	  cairo_restore(cr);
+	}
 
    return (0);
 }
@@ -367,13 +402,12 @@ gtk_databox_markers_real_draw (GtkDataboxGraph * graph,
 {
    GtkWidget *widget;
    GtkDataboxMarkers *markers = GTK_DATABOX_MARKERS (graph);
+   GtkDataboxMarkersPrivate *priv = gtk_databox_markers_get_instance_private (markers);
    GdkPoint points[3];
-   GdkPixmap *pixmap;
-   GdkGC *gc;
    PangoContext *context;
-   gfloat *X;
-   gfloat *Y;
-   guint len;
+   void *X;
+   void *Y;
+   guint len, maxlen;
    gint16 x;
    gint16 y;
    gint16 widget_width;
@@ -381,158 +415,200 @@ gtk_databox_markers_real_draw (GtkDataboxGraph * graph,
    GdkPoint coord;
    gint size;
    guint i;
+   cairo_t *cr;
+   GtkAllocation allocation;
+   gint16 *xpixels, *ypixels;
+   guint xstart, xstride, ystart, ystride;
+   GType xtype, ytype;
 
    g_return_if_fail (GTK_DATABOX_IS_MARKERS (markers));
    g_return_if_fail (GTK_IS_DATABOX (box));
 
    widget = GTK_WIDGET(box);
+   gtk_widget_get_allocation(widget, &allocation);
 
-   pixmap = gtk_databox_get_backing_pixmap (box);
    context = gtk_widget_get_pango_context(widget);
 
-   if (!(gc = gtk_databox_graph_get_gc(graph)))
-      gc = gtk_databox_graph_create_gc (graph, box);
-
    len = gtk_databox_xyc_graph_get_length (GTK_DATABOX_XYC_GRAPH (graph));
+   maxlen = gtk_databox_xyc_graph_get_maxlen (GTK_DATABOX_XYC_GRAPH (graph));
+
+   if (priv->pixelsalloc < len)
+   {
+   	priv->pixelsalloc = len;
+	priv->xpixels = (gint16 *)g_realloc(priv->xpixels, len * sizeof(gint16));
+	priv->ypixels = (gint16 *)g_realloc(priv->ypixels, len * sizeof(gint16));
+   }
+
+   xpixels = priv->xpixels;
+   ypixels = priv->ypixels;
+
    X = gtk_databox_xyc_graph_get_X (GTK_DATABOX_XYC_GRAPH (graph));
+   xstart = gtk_databox_xyc_graph_get_xstart (GTK_DATABOX_XYC_GRAPH (graph));
+   xstride = gtk_databox_xyc_graph_get_xstride (GTK_DATABOX_XYC_GRAPH (graph));
+   xtype = gtk_databox_xyc_graph_get_xtype (GTK_DATABOX_XYC_GRAPH (graph));
+   gtk_databox_values_to_xpixels(box, xpixels, X, xtype, maxlen, xstart, xstride, len);
+
    Y = gtk_databox_xyc_graph_get_Y (GTK_DATABOX_XYC_GRAPH (graph));
+   ystart = gtk_databox_xyc_graph_get_ystart (GTK_DATABOX_XYC_GRAPH (graph));
+   ystride = gtk_databox_xyc_graph_get_ystride (GTK_DATABOX_XYC_GRAPH (graph));
+   ytype = gtk_databox_xyc_graph_get_ytype (GTK_DATABOX_XYC_GRAPH (graph));
+   gtk_databox_values_to_ypixels(box, ypixels, Y, ytype, maxlen, ystart, ystride, len);
+
    size = gtk_databox_graph_get_size (graph);
 
-   widget_width = widget->allocation.width;
-   widget_height = widget->allocation.height;
+   widget_width = allocation.width;
+   widget_height = allocation.height;
 
-   for (i = 0; i < len; ++i)
-   {
-      coord.x = x = gtk_databox_value_to_pixel_x (box, X[i]);
-      coord.y = y = gtk_databox_value_to_pixel_y (box, Y[i]);
+   cr = gtk_databox_graph_create_gc (graph, box);
 
-      switch (markers->priv->type)
+	for (i = 0; i < len; ++i)
+	{
+		coord.x = x = xpixels[i];
+		coord.y = y = ypixels[i];
+
+		switch (priv->type)
+		{
+			case GTK_DATABOX_MARKERS_TRIANGLE:
+				switch (priv->markers_info[i].position)
+				{
+					case GTK_DATABOX_MARKERS_C:
+						y = y - size / 2;
+						points[0].x = x;
+						points[0].y = y;
+						points[1].x = x - size / 2;
+						points[1].y = y + size;
+						points[2].x = x + size / 2;
+						points[2].y = y + size;
+						break;
+
+					case GTK_DATABOX_MARKERS_N:
+						coord.y = y - 2 - size / 2;
+						y = y - 2;
+						points[0].x = x;
+						points[0].y = y;
+						points[1].x = x - size / 2;
+						points[1].y = y - size;
+						points[2].x = x + size / 2;
+						points[2].y = y - size;
+						break;
+
+					case GTK_DATABOX_MARKERS_E:
+						coord.x = x + 2 + size / 2;
+						x = x + 2;
+						points[0].x = x;
+						points[0].y = y;
+						points[1].x = x + size;
+						points[1].y = y + size / 2;
+						points[2].x = x + size;
+						points[2].y = y - size / 2;
+						break;
+
+					case GTK_DATABOX_MARKERS_S:
+						coord.y = y + 2 + size / 2;
+						y = y + 2;
+						points[0].x = x;
+						points[0].y = y;
+						points[1].x = x - size / 2;
+						points[1].y = y + size;
+						points[2].x = x + size / 2;
+						points[2].y = y + size;
+						break;
+
+					case GTK_DATABOX_MARKERS_W:
+					default:
+						coord.x = x - 2 - size / 2;
+						x = x - 2;
+						points[0].x = x;
+						points[0].y = y;
+						points[1].x = x - size;
+						points[1].y = y + size / 2;
+						points[2].x = x - size;
+						points[2].y = y - size / 2;
+						break;
+				}
+				cairo_move_to(cr, points[0].x + 0.5, points[0].y + 0.5);
+				cairo_line_to(cr, points[1].x + 0.5, points[1].y + 0.5);
+				cairo_line_to(cr, points[2].x + 0.5, points[2].y + 0.5);
+				cairo_close_path  (cr);
+				cairo_fill(cr);
+				break;
+				/* End of GTK_DATABOX_MARKERS_TRIANGLE */
+
+				case GTK_DATABOX_MARKERS_SOLID_LINE:
+				case GTK_DATABOX_MARKERS_DASHED_LINE:
+				switch (priv->markers_info[i].position)
+				{
+					case GTK_DATABOX_MARKERS_C:
+						points[0].x = x;
+						points[0].y = 0;
+						points[1].x = x;
+						points[1].y = widget_height;
+						break;
+
+					case GTK_DATABOX_MARKERS_N:
+						points[0].x = x;
+						points[0].y = 0;
+						points[1].x = x;
+						points[1].y = widget_height;
+						break;
+
+					case GTK_DATABOX_MARKERS_E:
+						points[0].x = 0;
+						points[0].y = y;
+						points[1].x = widget_width;
+						points[1].y = y;
+						break;
+
+					case GTK_DATABOX_MARKERS_S:
+						points[0].x = x;
+						points[0].y = 0;
+						points[1].x = x;
+						points[1].y = widget_height;
+						break;
+
+					case GTK_DATABOX_MARKERS_W:
+					default:
+						points[0].x = 0;
+						points[0].y = y;
+						points[1].x = widget_width;
+						points[1].y = y;
+						break;
+				}
+				cairo_move_to(cr, points[0].x + 0.5, points[0].y + 0.5);
+				cairo_line_to(cr, points[1].x + 0.5, points[1].y + 0.5);
+				cairo_stroke(cr);
+
+				break;
+				/* End of GTK_DATABOX_MARKERS_LINE */
+
+				case GTK_DATABOX_MARKERS_NONE:
+				default:
+					break;
+		}
+
+      if (priv->markers_info[i].text)
       {
-      case GTK_DATABOX_MARKERS_TRIANGLE:
-	 switch (markers->priv->markers_info[i].position)
-	 {
-	 case GTK_DATABOX_MARKERS_C:
-	    y = y - size / 2;
-	    points[0].x = x;
-	    points[0].y = y;
-	    points[1].x = x - size / 2;
-	    points[1].y = y + size;
-	    points[2].x = x + size / 2;
-	    points[2].y = y + size;
-	    break;
-	 case GTK_DATABOX_MARKERS_N:
-	    coord.y = y - 2 - size / 2;
-	    y = y - 2;
-	    points[0].x = x;
-	    points[0].y = y;
-	    points[1].x = x - size / 2;
-	    points[1].y = y - size;
-	    points[2].x = x + size / 2;
-	    points[2].y = y - size;
-	    break;
-	 case GTK_DATABOX_MARKERS_E:
-	    coord.x = x + 2 + size / 2;
-	    x = x + 2;
-	    points[0].x = x;
-	    points[0].y = y;
-	    points[1].x = x + size;
-	    points[1].y = y + size / 2;
-	    points[2].x = x + size;
-	    points[2].y = y - size / 2;
-	    break;
-	 case GTK_DATABOX_MARKERS_S:
-	    coord.y = y + 2 + size / 2;
-	    y = y + 2;
-	    points[0].x = x;
-	    points[0].y = y;
-	    points[1].x = x - size / 2;
-	    points[1].y = y + size;
-	    points[2].x = x + size / 2;
-	    points[2].y = y + size;
-	    break;
-	 case GTK_DATABOX_MARKERS_W:
-	    coord.x = x - 2 - size / 2;
-	    x = x - 2;
-	    points[0].x = x;
-	    points[0].y = y;
-	    points[1].x = x - size;
-	    points[1].y = y + size / 2;
-	    points[2].x = x - size;
-	    points[2].y = y - size / 2;
-	    break;
-	 }
-	 gdk_draw_polygon (pixmap, gc, TRUE, points, 3);
-	 break;
-	 /* End of GTK_DATABOX_MARKERS_TRIANGLE */
-      case GTK_DATABOX_MARKERS_SOLID_LINE:
-      case GTK_DATABOX_MARKERS_DASHED_LINE:
-	 switch (markers->priv->markers_info[i].position)
-	 {
-	 case GTK_DATABOX_MARKERS_C:
-	    points[0].x = x;
-	    points[0].y = 0;
-	    points[1].x = x;
-	    points[1].y = widget_height;
-	    break;
-	 case GTK_DATABOX_MARKERS_N:
-	    points[0].x = x;
-	    points[0].y = 0;
-	    points[1].x = x;
-	    points[1].y = widget_height;
-	    break;
-	 case GTK_DATABOX_MARKERS_E:
-	    points[0].x = 0;
-	    points[0].y = y;
-	    points[1].x = widget_width;
-	    points[1].y = y;
-	    break;
-	 case GTK_DATABOX_MARKERS_S:
-	    points[0].x = x;
-	    points[0].y = 0;
-	    points[1].x = x;
-	    points[1].y = widget_height;
-	    break;
-	 case GTK_DATABOX_MARKERS_W:
-	    points[0].x = 0;
-	    points[0].y = y;
-	    points[1].x = widget_width;
-	    points[1].y = y;
-	    break;
-	 }
+		if (!priv->markers_info[i].label)
+		{
+			priv->markers_info[i].label =
+			pango_layout_new (context);
+			pango_layout_set_text (priv->markers_info[i].label,
+			priv->markers_info[i].text, -1);
+		}
 
-	 gdk_draw_line (pixmap, gc,
-			points[0].x, points[0].y, points[1].x, points[1].y);
-	 break;
-	 /* End of GTK_DATABOX_MARKERS_LINE */
-
-      case GTK_DATABOX_MARKERS_NONE:
-      default:
-	 break;
-      }
-
-      if (markers->priv->markers_info[i].text)
-      {
-	 if (!markers->priv->markers_info[i].label)
-	 {
-	    markers->priv->markers_info[i].label =
-	       pango_layout_new (context);
-	    pango_layout_set_text (markers->priv->markers_info[i].label,
-				   markers->priv->markers_info[i].text, -1);
-	 }
-
-	 if (markers->priv->type == GTK_DATABOX_MARKERS_SOLID_LINE
-	     || markers->priv->type == GTK_DATABOX_MARKERS_DASHED_LINE)
+	 if (priv->type == GTK_DATABOX_MARKERS_SOLID_LINE
+	     || priv->type == GTK_DATABOX_MARKERS_DASHED_LINE)
 	 {
 	    gint width;
 	    gint height;
-	    pango_layout_get_pixel_size (markers->priv->markers_info[i].label,
+	    pango_layout_get_pixel_size (priv->markers_info[i].label,
 					 &width, &height);
 
 	    width = (width + 1) / 2 + 2;
 	    height = (height + 1) / 2 + 2;
 	    size = 0;
 
-	    switch (markers->priv->markers_info[i].position)
+	    switch (priv->markers_info[i].position)
 	    {
 	    case GTK_DATABOX_MARKERS_C:
 	       break;
@@ -551,15 +627,16 @@ gtk_databox_markers_real_draw (GtkDataboxGraph * graph,
 	    }
 	 }
 
-	 gtk_databox_label_write_at (pixmap,
-				     markers->priv->markers_info[i].label,
-				     markers->priv->label_gc, coord,
-				     markers->priv->markers_info[i].
+	 gtk_databox_label_write_at (cr,
+				     priv->markers_info[i].label,
+				     coord,
+				     priv->markers_info[i].
 				     label_position, (size + 1) / 2 + 2,
-				     markers->priv->markers_info[i].boxed);
+				     priv->markers_info[i].boxed);
       }
    }
 
+   cairo_destroy(cr);
    return;
 }
 
@@ -576,13 +653,14 @@ gtk_databox_markers_set_position (GtkDataboxMarkers * markers,
 				 guint index,
 				 GtkDataboxMarkersPosition position)
 {
+   GtkDataboxMarkersPrivate *priv = gtk_databox_markers_get_instance_private (markers);
    guint len;
 
    g_return_if_fail (GTK_DATABOX_IS_MARKERS (markers));
    len = gtk_databox_xyc_graph_get_length (GTK_DATABOX_XYC_GRAPH (markers));
    g_return_if_fail (index < len);
 
-   markers->priv->markers_info[index].position = position;
+   priv->markers_info[index].position = position;
 }
 
 /**
@@ -601,21 +679,22 @@ gtk_databox_markers_set_label (GtkDataboxMarkers * markers,
 			      GtkDataboxMarkersTextPosition label_position,
 			      gchar * text, gboolean boxed)
 {
+   GtkDataboxMarkersPrivate *priv = gtk_databox_markers_get_instance_private (markers);
    guint len;
 
    g_return_if_fail (GTK_DATABOX_IS_MARKERS (markers));
    len = gtk_databox_xyc_graph_get_length (GTK_DATABOX_XYC_GRAPH (markers));
    g_return_if_fail (index < len);
 
-   markers->priv->markers_info[index].label_position = label_position;
-   if (markers->priv->markers_info[index].text)
-      g_free (markers->priv->markers_info[index].text);
-   markers->priv->markers_info[index].text = g_strdup (text);
-   markers->priv->markers_info[index].boxed = boxed;
+   priv->markers_info[index].label_position = label_position;
+   if (priv->markers_info[index].text)
+      g_free (priv->markers_info[index].text);
+   priv->markers_info[index].text = g_strdup (text);
+   priv->markers_info[index].boxed = boxed;
 
-   if (markers->priv->markers_info[index].label)
+   if (priv->markers_info[index].label)
    {
-      pango_layout_set_text (markers->priv->markers_info[index].label,
-			     markers->priv->markers_info[index].text, -1);
+      pango_layout_set_text (priv->markers_info[index].label,
+			     priv->markers_info[index].text, -1);
    }
 }
