@@ -14,11 +14,19 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include <gtkdatabox_scale.h>
 
+/**
+ * gtk_databox_scale_type_get_type
+ *
+ * Getter function for the #GtkDataboxScaleType Gtype.
+ *
+ * Return value: #GType of #GtkDataboxScaleType.
+ *
+ */
 GType
 gtk_databox_scale_type_get_type (void)
 {
@@ -29,6 +37,7 @@ gtk_databox_scale_type_get_type (void)
       static const GEnumValue values[] = {
          { GTK_DATABOX_SCALE_LINEAR, "GTK_DATABOX_SCALE_LINEAR", "linear" },
          { GTK_DATABOX_SCALE_LOG, "GTK_DATABOX_SCALE_LOG", "log" },
+         { GTK_DATABOX_SCALE_LOG2, "GTK_DATABOX_SCALE_LOG2", "log2" },
          { 0, NULL, NULL }};
       type = g_enum_register_static (g_intern_static_string ("GtkDataboxScaleType"), values);
    }
